DesignNode class abstract

A positioned, selectable item on a DesignDocument (text, image, or custom).

Background Fill is stored as BackgroundNode but is not selectable.

Implementers

Constructors

DesignNode({required String id, required String type, required Rect frame, required int zIndex, double rotation = 0, double scaleX = 1, double scaleY = 1})
const

Properties

frame Rect
final
hashCode int
The hash code for this object.
no setteroverride
id String
final
rotation double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaleX double
final
scaleY double
final
type String
final
zIndex int
final

Methods

copyWith({Rect? frame, int? zIndex, double? rotation, double? scaleX, double? scaleY}) DesignNode
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override